package com.yanzhu.jh.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectChecking;
import com.yanzhu.jh.project.service.ISurProjectCheckingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目验收Controller
 * 
 * @author JiangYuQi
 * @date 2023-08-18
 */
@RestController
@RequestMapping("/project/projectChecking")
public class SurProjectCheckingController extends BaseController
{
    @Autowired
    private ISurProjectCheckingService surProjectCheckingService;

    /**
     * 查询项目验收列表
     */
    @PreAuthorize("@ss.hasPermi('project:projectChecking:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurProjectChecking surProjectChecking)
    {
        startPage();
        List<SurProjectChecking> list = surProjectCheckingService.selectSurProjectCheckingList(surProjectChecking);
        return getDataTable(list);
    }

    /**
     * 导出项目验收列表
     */
    @PreAuthorize("@ss.hasPermi('project:projectChecking:export')")
    @Log(title = "项目验收", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectChecking surProjectChecking)
    {
        List<SurProjectChecking> list = surProjectCheckingService.selectSurProjectCheckingList(surProjectChecking);
        ExcelUtil<SurProjectChecking> util = new ExcelUtil<SurProjectChecking>(SurProjectChecking.class);
        util.exportExcel(response, list, "项目验收数据");
    }

    /**
     * 获取项目验收详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:projectChecking:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectCheckingService.selectSurProjectCheckingById(id));
    }

    /**
     * 新增项目验收
     */
    @PreAuthorize("@ss.hasPermi('project:projectChecking:add')")
    @Log(title = "项目验收", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurProjectChecking surProjectChecking)
    {
        return toAjax(surProjectCheckingService.insertSurProjectChecking(surProjectChecking));
    }

    /**
     * 修改项目验收
     */
    @PreAuthorize("@ss.hasPermi('project:projectChecking:edit')")
    @Log(title = "项目验收", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectChecking surProjectChecking)
    {
        return toAjax(surProjectCheckingService.updateSurProjectChecking(surProjectChecking));
    }

    /**
     * 删除项目验收
     */
    @PreAuthorize("@ss.hasPermi('project:projectChecking:remove')")
    @Log(title = "项目验收", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectCheckingService.deleteSurProjectCheckingByIds(ids));
    }
}
