package com.yanzhu.jh.project.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectCheckingMapper;
import com.yanzhu.jh.project.domain.SurProjectChecking;
import com.yanzhu.jh.project.service.ISurProjectCheckingService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 项目验收Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2023-08-18
 */
@Service
public class SurProjectCheckingServiceImpl implements ISurProjectCheckingService 
{
    @Autowired
    private SurProjectCheckingMapper surProjectCheckingMapper;

    /**
     * 查询项目验收
     * 
     * @param id 项目验收主键
     * @return 项目验收
     */
    @Override
    public SurProjectChecking selectSurProjectCheckingById(Long id)
    {
        return surProjectCheckingMapper.selectSurProjectCheckingById(id);
    }

    /**
     * 查询项目验收列表
     * 
     * @param surProjectChecking 项目验收
     * @return 项目验收
     */
    @Override
    public List<SurProjectChecking> selectSurProjectCheckingList(SurProjectChecking surProjectChecking)
    {
        return surProjectCheckingMapper.selectSurProjectCheckingList(surProjectChecking);
    }

    /**
     * 新增项目验收
     * 
     * @param surProjectChecking 项目验收
     * @return 结果
     */
    @Override
    public int insertSurProjectChecking(SurProjectChecking surProjectChecking)
    {
        surProjectChecking.setCreateBy(SecurityUtils.getUsername());
        surProjectChecking.setCreateTime(DateUtils.getNowDate());
        return surProjectCheckingMapper.insertSurProjectChecking(surProjectChecking);
    }

    /**
     * 修改项目验收
     * 
     * @param surProjectChecking 项目验收
     * @return 结果
     */
    @Override
    public int updateSurProjectChecking(SurProjectChecking surProjectChecking)
    {
        surProjectChecking.setUpdateBy(SecurityUtils.getUsername());
        surProjectChecking.setUpdateTime(DateUtils.getNowDate());
        return surProjectCheckingMapper.updateSurProjectChecking(surProjectChecking);
    }

    /**
     * 批量删除项目验收
     * 
     * @param ids 需要删除的项目验收主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectCheckingByIds(Long[] ids)
    {
        return surProjectCheckingMapper.deleteSurProjectCheckingByIds(ids);
    }

    /**
     * 删除项目验收信息
     * 
     * @param id 项目验收主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectCheckingById(Long id)
    {
        return surProjectCheckingMapper.deleteSurProjectCheckingById(id);
    }
}
